@@ -113,6 +113,10 @@ def col_dtype_converter(df:pd.DataFrame, date_cols:list=False, day_first = False
     return df
 
 def excel_writer(df:pd.DataFrame, output_file:Path, sheet_name):
+    '''
+    Checks if file / sheet already exists. If yes, appends data to existing file / sheet else creates new
+    file / sheet.
+    '''
     if output_file.exists():
         # checking last used row before appending
         wb = load_workbook(output_file, read_only=True)
@@ -142,3 +146,12 @@ def df_col_search(df:pd.DataFrame, srch_string: str):
         if srch_string in col.lower():
             col_list.append(col)
     return col_list
+
+def dtype_to_df(df: pd.DataFrame)->None:
+    '''
+    Accepts a dataframe and returns df containing column dtypes
+    '''
+    df_cols = pd.DataFrame(columns=['Type'], data=df.dtypes)
+    df_cols.index.name = 'Col'
+    df_cols.reset_index(inplace=True)
+    return df_cols
